Cas Summary Parser
==================
This is a Python library to parse CAS Summary PDFs generated by CAMS Online or KFinTech. 
Note that this only parses the summary and not the detailed version of the pdf. 


Examples
--------
.. code-block:: python

    from cassummaryparser import CasParser
    
    file_path = './your.pdf'
    parser = CasParser(file=file_path, password='')
    
    data = parser.parse()
    
    print(data[0])

.. code-block:: python

    CasRecord(folio_no='51022181991/0 ', isin='INF966L01986', scheme_name='166TPDGG - quant ELSS Tax Saver Fund - Direct Plan Total', cost_value='20,000.000', unit_balance=74.816, nav_date='17-Jan-2024', nav='360.5733', market_value='26,976.65', registrar='KFINTECH')

